@@ -1,34 +1,24 @@
 from __future__ import annotations
-import os
-import urllib.parse
 
 from abc import abstractmethod
-from typing import Mapping, Optional, List, Any, Type, TYPE_CHECKING
-
+from typing import TYPE_CHECKING, Any, List, Optional
 
 from dcbench.common.bundle import RelationalBundle
 
-from .artefact import Artefact, ArtefactContainer
-from ..constants import (
-    LOCAL_DIR,
-    PROBLEMS_DIR,
-    PUBLIC_REMOTE_URL,
-    HIDDEN_ARTEFACTS_URL,
-)
-from .download_utils import download_and_extract_archive
+from ..constants import PROBLEMS_DIR
+from .artefact import ArtefactContainer
 
 if TYPE_CHECKING:
     from .solution import Solution
 
 
 class Problem(ArtefactContainer):
-
+    container_id = "problem"
     task_id: str
     result_metrics: Optional[List[str]] = None
 
     container_dir = PROBLEMS_DIR
 
-
     @property
     def solutions(self) -> RelationalBundle[Solution]:
         if self._solutions is None:
@@ -44,14 +34,10 @@ class Problem(ArtefactContainer):
             self._solutions = RelationalBundle(solutions, attributes)
         return self._solutions
 
-    @classmethod
-    def list(cls) -> List[str]:
-        raise NotImplementedError
-
     @abstractmethod
     def solve(self, **kwargs: Any) -> Solution:
         raise NotImplementedError
 
     @abstractmethod
-    def evaluate(self, solution: Solution) -> Result:
+    def evaluate(self, solution: Solution):
         raise NotImplementedError
