@@ -1,19 +1,19 @@
-import ray
-import pandas as pd
-
 from typing import List
+
+import pandas as pd
+import ray
+
 from dcbench.common.method import Method
-from dcbench.common.scenario import Scenario
 
 
 @ray.remote
-def _solve_scenario(scenario: Scenario, method: Method):
+def _solve_scenario(scenario, method: Method):
     solution = scenario.solve(method)
     solution.dump()
-    return solution 
+    return solution
 
 
-def solve(scenarios: ProblemSet, methods: List[Method]) -> pd.DataFrame:
+def solve(scenarios, methods: List[Method]) -> pd.DataFrame:
     method_refs = [ray.put(method) for method in methods]
     solution_refs = []
     for scenario in scenarios:
